# Generated by Django 3.2.5 on 2021-08-08 01:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0053_characteraudit_last_update_contacts'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='charactertitle',
            name='character',
        ),
        migrations.AddField(
            model_name='characteraudit',
            name='last_update_titles',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.AddField(
            model_name='characterroles',
            name='titles',
            field=models.ManyToManyField(to='corptools.CharacterTitle'),
        ),
        migrations.AddField(
            model_name='charactertitle',
            name='corporation_id',
            field=models.BigIntegerField(),
            preserve_default=False,
        ),
    ]
