# Generated by Django 4.2.13 on 2024-09-08 09:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0109_corptoolsconfiguration_disable_verification_assets_and_more'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='OrePrice',
            new_name='TypePrice',
        ),
    ]
