# Generated by Django 4.2.16 on 2024-09-23 00:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0017_alliance_and_corp_names_are_not_unique'),
        ('corptools', '0111_corptoolsconfiguration_disable_update_assets_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='corptoolsconfiguration',
            name='holding_corps',
            field=models.ManyToManyField(blank=True, to='eveonline.evecorporationinfo'),
        ),
    ]
