# Generated by Django 3.1.6 on 2021-03-23 15:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0044_auto_20210322_0805'),
    ]

    operations = [
        migrations.AlterField(
            model_name='characterasset',
            name='id',
            field=models.BigAutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='corpasset',
            name='id',
            field=models.BigAutoField(primary_key=True, serialize=False),
        ),
    ]
