# Generated by Django 4.2.5 on 2023-09-16 09:41

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0091_assetsfilter_count_message_only_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Poco',
            fields=[
                ('id', models.AutoField(auto_created=True,
                 primary_key=True, serialize=False, verbose_name='ID')),
                ('office_id', models.BigIntegerField()),
                ('alliance_tax_rate', models.FloatField(default=None, null=True)),
                ('corporation_tax_rate', models.FloatField(default=None, null=True)),
                ('terrible_standing_tax_rate',
                 models.FloatField(default=None, null=True)),
                ('bad_standing_tax_rate', models.FloatField(default=None, null=True)),
                ('neutral_standing_tax_rate',
                 models.FloatField(default=None, null=True)),
                ('good_standing_tax_rate', models.FloatField(
                    default=None, null=True)),
                ('excellent_standing_tax_rate',
                 models.FloatField(default=None, null=True)),
                ('reinforce_exit_end', models.IntegerField()),
                ('reinforce_exit_start', models.IntegerField()),
                ('standing_level', models.CharField(
                    default=None, max_length=150, null=True)),
                ('allow_access_with_standings',
                 models.BooleanField(default=None, null=True)),
                ('allow_alliance_access', models.BooleanField(
                    default=None, null=True)),
                ('system_id', models.IntegerField()),
                ('name', models.CharField(blank=True,
                 default=None, max_length=150, null=True)),
                ('corporation', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE,
                 related_name='ct_poco', to='corptools.corporationaudit')),
                ('planet', models.ForeignKey(default=None, null=True,
                 on_delete=django.db.models.deletion.SET_NULL, to='corptools.mapsystemplanet')),
                ('system_name', models.ForeignKey(default=None, null=True,
                 on_delete=django.db.models.deletion.SET_NULL, to='corptools.mapsystem')),
            ],
        ),
    ]
