# Generated by Django 4.0.10 on 2023-11-25 09:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0098_migrate_role_filters'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='rolefilter',
            name='alliance_filter',
        ),
        migrations.RemoveField(
            model_name='rolefilter',
            name='corp_filter',
        ),
    ]
