# Generated by Django 2.2.9 on 2020-05-11 08:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0009_auto_20200511_0816'),
    ]

    operations = [
        migrations.AlterField(
            model_name='characterasset',
            name='item_id',
            field=models.BigIntegerField(),
        ),
        migrations.AlterField(
            model_name='corpasset',
            name='item_id',
            field=models.BigIntegerField(),
        ),
    ]
