.char-portrait {
  width: 300px;
  height: 300px;
  position: relative;
}

.corp-logo {
  position: absolute;
  bottom: 0;
  left: 0;
  margin: 5px;
  width: 90px;
  height: 90px;
}

.alli-logo {
  position: absolute;
  bottom: 0;
  right: 0;
  margin: 5px;
  width: 90px;
  height: 90px;
}
