# Generated by Django 2.2.9 on 2020-05-07 11:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0003_auto_20200507_1115'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mapsystem',
            name='security_class',
            field=models.CharField(default=None, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='mapsystem',
            name='star_id',
            field=models.IntegerField(default=None, null=True),
        ),
    ]
