.menu-spinner-size{height:30px;width:30px;margin-top:12.5px}.spinner-size{height:30px;width:30px;margin:200px}.error-size{width:100px;height:100px;margin:200px 200px 15px}.text-margin{margin-bottom:185px}@keyframes shake{10%,90%{transform:translate3d(-1px,0,0)}20%,80%{transform:translate3d(2px,0,0)}30%,50%,70%{transform:translate3d(-4px,0,0)}40%,60%{transform:translate3d(4px,0,0)}}.error-anim{animation:shake .82s cubic-bezier(.36,.07,.19,.97) both;animation-iteration-count:infinite}@keyframes updown{10%,90%{transform:translate3d(0,-2px,0)}20%,80%{transform:translate3d(0,2px,0)}30%,50%,70%{transform:translate3d(0,-4px,0)}40%,60%{transform:translate3d(0,4px,0)}}.arrow-anim{animation:updown 5s cubic-bezier(.36,.07,.19,.97) both;animation-iteration-count:infinite}@keyframes spin{0%{transform:rotate(0)}to{transform:rotate(359deg)}}.glyphicon-refresh-animate{-animation:spin 2s infinite linear;-ms-animation:spin 2s infinite linear;-webkit-animation:spin 2s infinite linear;-moz-animation:spin 2s infinite linear}.flex-image-text{display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-evenly;align-items:center;align-content:center}.padded-label{margin:5px}.start{border-right:3px dotted;padding:15px;margin:5px;width:325px;text-align:right}@media only screen and (max-width: 1250px){.start{width:100%;border-left:3px dotted;border-right:none;text-align:left}}.end{border-left:3px dotted;padding:15px;margin:5px;width:325px;text-align:left}@media only screen and (max-width: 1250px){.end{width:100%;border-right:3px dotted;border-left:none;text-align:right}}.gate-active{border-color:#0ff!important}.gate-inactive{border-color:red!important}.gate-unknown{border-color:orange!important}.link-line{border-top:2px dashed grey;margin:0 20px}.bridge-div{margin:15px}*{margin:0;padding:0}.flex{display:flex;height:80px;align-items:center}.child{margin-right:20px}.child-end{margin-left:auto}.fill-width{overflow:auto}.float-left{float:left}.flex-container{display:flex;align-items:center;justify-content:center;align-content:center;flex-wrap:wrap;flex-direction:row}.flex-wide{justify-content:space-between;flex-wrap:nowrap}.flex-wide-child{width:700px}.flex-container-pull-right{display:flex;align-items:flex-end;justify-content:center;align-content:center;flex-direction:row}.flex-container-vert-fill{display:flex;align-items:stretch;justify-content:center;align-content:stretch;flex-wrap:wrap;flex-direction:column}.flex-child{margin:10px}.flex-body{align-items:center}.table-div{height:250px;width:400px;overflow-y:auto}.table-div-no-hight{height:unset}.table-div-fill{width:auto}.table-div::-webkit-scrollbar{width:3;background:transparent}.table-div::-webkit-scrollbar-thumb{background-color:#375a7f4b;border-left:15px solid transparent;background-clip:padding-box}.no-wrap{white-space:nowrap}@media only screen and (max-width: 1400px){.info-hide{display:none}}@media only screen and (max-width: 1000px){.association-hide{display:none}}.flex-label-container{display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:flex-start;align-items:stretch;align-content:stretch}.flex-label{margin:2px}.flex-select{flex:1;margin:2px}.flex-select-size{width:300px}
