# Generated by Django 4.0.8 on 2022-12-22 01:51

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0079_characteraudit_last_update_location_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='characterlocation',
            name='character',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE,
                                       related_name='location', to='corptools.characteraudit'),
        ),
    ]
