# Generated by Django 3.2.12 on 2022-02-15 12:22

from django.db import migrations


def add_settings(apps, schema_editor):
    CTConfiguration = apps.get_model(
        'corptools', 'CorptoolsConfiguration')

    CTConfiguration.objects.create()


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0069_corptoolsconfiguration'),
    ]

    operations = [
        migrations.RunPython(add_settings)
    ]
